from sys import argv, stdin, exit
from re import match

assert len(argv)==3, "correct usage: python3 %s our_output contestants_output" % argv[0]

our_output_tokens = open(argv[1],'r').read().split()

try:
    their_output_tokens = open(argv[2],'r').read().split()
except:
    print("Wrong answer: Failed to parse the submission (binary file?)")
    exit(1)

# this is just a standard pseudorandom generator
class PRNG:
    def __init__(self, seed): self.seed = seed

    def _random(self):
        M, A = 2147483647, 16807
        Q, R = M // A, M % A
        self.seed = A * (self.seed % Q) - R * (self.seed // Q)
        if self.seed <= 0: self.seed += M
        return self.seed

    def randint(self, lo, hi):
        return lo + self._random() % (hi-lo)

def median(a, b, c):
    if a > b: a, b = b, a
    if a > c: a, c = c, a
    if b > c: b, c = c, b
    return b

def modify(A, x, y, magic):
    if (A[x] > A[y]) or (not magic):
        A[x], A[y] = A[y], A[x]

# this is the main function
def k2_sort(A):
    generator = PRNG(589)

    N = len(A)
    L = 1
    while (1<<L) < N: L += 1
    lo = - ( ((1<<L) - N) // 2 )
   
    for superphase in range(2):
        for phase in range(1,L+1):
            for subphase in range(phase,0,-1):
                if phase == L and subphase == L:
                    for i in range(1<<(L-1)):
                        x, y = lo+i, lo+(1<<L)-1-i
                        if (x >= 0) and (y < N):
                            modify(A, x, y, L*superphase+phase >= 2*(L-1))
                for block in range(1<<(L-subphase)):
                    xlo  = median( 0, N, lo + (block << subphase) )
                    xmed = median( 0, N, lo + (block << subphase) + (1<<(subphase-1)) )
                    xhi  = median( 0, N, lo + (block << subphase) + (1<<subphase) )
                    if xlo == xmed or xmed == xhi: continue
                    for comparison in range(521):
                        x = generator.randint(xlo,xmed)
                        y = generator.randint(xmed,xhi)
                        modify(A, x, y, L*superphase+phase >= 2*(L-1))

try:
    assert len(their_output_tokens) > 0, "Wrong answer: Your output file was empty."
    
    try:
        n = int( their_output_tokens[0] )
    except:
        assert False, "Wrong answer: The first token in your output should be the length of the array."

    assert n+1 == len(their_output_tokens), "Wrong answer: The length of the array does not match the number of array elements you provided."

    try:
        A = [ int(x) for x in their_output_tokens[1:] ]
    except:
        assert False, "Wrong answer: All array elements must be integers."

    for a in A: assert 0 <= a < 2**32, "Wrong answer: All array elements must be valid 32-bit unsigned integers."

    assert int(our_output_tokens[0]) == n, "Wrong answer: The array in your output is not a correct answer."

    k2_sort(A)
    
    B = A.copy()
    B.sort()

    assert A != B, "Wrong answer: The array in your output is not a correct answer."

except Exception as error_message:
    print(error_message)
    exit(1)

print("OK")
